package in.bench.resources.msaccess.db.example;
import java.io.*;
import java.awt.Desktop;
import java.sql.*;
import simplenlg.features.Feature;
import simplenlg.features.Tense;
import simplenlg.framework.*;
import simplenlg.lexicon.*;
import simplenlg.realiser.english.*;
import simplenlg.phrasespec.*;
import java.util.Scanner;
import java.util.Arrays;


public class BasketballReport {


    public static void main(String[] args) throws IOException {
        //Set up writing the output to a text file and opening that file
        File file = new File("C:\\Users\\Jacob\\LegendsProject\\CommishCorner.txt");
        //Make sure this ^^^^^ has the path to where you want the file to go, as well as the name
        PrintWriter out = new PrintWriter(file);
        if(!Desktop.isDesktopSupported()){
            System.out.println("not supported");
            return;
        }
        Desktop desktop = Desktop.getDesktop();

        //sets up the SimpleNLG commands
        Connection conn = null;
        Statement stmt;
        Lexicon lexicon = Lexicon.getDefaultLexicon();
        NLGFactory nlgFactory = new NLGFactory(lexicon);

        //Just a bit of text to make the file look nice
        out.println("This weeks games: " + "\n");
        out.println("");

        try{
            // STEP 1: Loading or registering Oracle JDBC driver class
            Class.forName("net.ucanaccess.jdbc.UcanaccessDriver");
            String URL = "jdbc:ucanaccess://C:\\Users\\Jacob\\LegendsProject\\Legends_Progress 12-8(1) with time corrections for matches & teams.accdb";   //ex. jdbc:ucanaccess://D:/WORKSPACE/Java-JDBC/BaskestballPlayer.accdb"

            //STEP 3: Open a connection
            conn = DriverManager.getConnection(URL);

            //STEP 4: Input dates, execute a query
            System.out.println("Creating statement...");
            stmt = conn.createStatement();


            Scanner myObj = new Scanner(System.in);  // Create a Scanner object for dates
            System.out.println("Enter dates for report. Enter Date 1: (format: 'mm/dd/yyyy')"); //Make sure you put quotes around the dates you specify, ex. "12/25/2015"
            String DATE1 = myObj.nextLine();

            Scanner myObj2 = new Scanner(System.in);  // Create a Scanner object for dates
            System.out.println("Enter Date 2: (format: 'mm/dd/yyyy')"); //Make sure you put quotes around the dates you specify, ex. "12/25/2015"
            String DATE2 = myObj2.nextLine();

            String sql = "SELECT * FROM [Basketball-Matches] WHERE Date >= TO_DATE(" + DATE1 + ",'MM/DD/YYYY') AND Date <= TO_DATE(" + DATE2 + ",'MM/DD/YYYY');";

            ResultSet rs = stmt.executeQuery(sql);


            //STEP 5: get team names, scores, [future] player stats
            Realiser realiser = new Realiser();

            //STEP 6: Run SimpleNLG commands to write the statements and print the output
            String sql1 = "SELECT Date, Team, Opponent, [For], Against FROM [Basketball-Matches] WHERE Date >= TO_DATE(" + DATE1 + ",'MM/DD/YYYY') AND Date <= TO_DATE(" + DATE2 + ",'MM/DD/YYYY');";
            ResultSet rs1 = stmt.executeQuery(sql1);
            while (rs1.next()) {
                String Date = rs1.getString("Date");
                Date = Date.replace("00:00:00.000000", "");
                String Team = rs1.getString("Team");
                String Opponent = rs1.getString("Opponent");
                int For = rs1.getInt("For");
                int Against = rs1.getInt("Against");

                // Home team wins by 30 or more -- BLOWOUT SCENARIO
                if ((For > Against) && ((For - Against) >= 30)) {        // Opponent loses
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "play", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    p1.addComplement(pp);
                    p1.addComplement("in an absolute blowout");
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase(Team);
                    NPPhraseSpec object = nlgFactory.createNounPhrase(Opponent);
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("dismantle");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("in a game that never had a chance of being close. ");
                    p2.addComplement("The final score was a brutal " + For + " to " + Against);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);
                }

                //Home team wins by more than 15 points, but less than 30 -- SOLID WIN SCENARIO
                else if ((For > Against) && (15 <= (For - Against) && (For - Against) < 30)) {        // Opponent loses
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "faced off against", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.addComplement(pp);
                    p1.addComplement("in a decisive match");
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase(Team);
                    NPPhraseSpec object = nlgFactory.createNounPhrase(Opponent);
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("defeated");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("in a comfortable victory,");
                    p2.addComplement("outscoring them " + For + " to " + Against);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);
                }

                //Home team wins by less than 15 -- CLOSE WIN
                else if (For > Against) {
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "face", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.addComplement(pp);
                    p1.addComplement("in a close game");
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase(Team);
                    NPPhraseSpec object = nlgFactory.createNounPhrase(Opponent);
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("defeated");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("just barely, managing to get the win");
                    p2.addComplement("with a final score of " + For + " to " + Against);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);

                }
                // Away team wins by over 30 -- BLOWOUT SCENARIO
                else if ((For < Against) && ((Against - For) >= 30)) {        // Opponent loses
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "play", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    p1.addComplement(pp);
                    p1.addComplement("in an absolute blowout");
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase(Team);
                    NPPhraseSpec object = nlgFactory.createNounPhrase(Opponent);
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("dismantle");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("who never even had a chance. ");
                    p2.addComplement("The final score was a brutal " + Against + " to " + For);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);
                }

                //Away team wins by more than 15 points, but less than 30 -- SOLID WIN SCENARIO
                else if ((For < Against) && (15 <= (Against - For) && (Against - For) < 30)) {        // Opponent loses
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "faced off against", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.addComplement(pp);
                    p1.addComplement("in a decisive match");
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase(Team);
                    NPPhraseSpec object = nlgFactory.createNounPhrase(Opponent);
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("defeated");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("comfortably,");
                    p2.addComplement("outscoring them " + Against + " to " + For);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);
                }

                //AWAY team wins by less than 15 -- CLOSE GAME SCENARIO
                else if (For < Against) {
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "faced", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.addComplement(pp);
                    p1.addComplement("in a close game");
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase(Team);
                    NPPhraseSpec object = nlgFactory.createNounPhrase(Opponent);
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("beat");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("just barely sneaking out a win.");
                    p2.addComplement("That final score was " + Against + " to " + For);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);

                } else if (For == Against) {        // tied game
                    SPhraseSpec p1 = nlgFactory.createClause(Team, "face off against", Opponent);
                    PPPhraseSpec pp = nlgFactory.createPrepositionPhrase("on", Date);
                    p1.addComplement(pp);
                    p1.addComplement("in a close match!");
                    p1.setFeature(Feature.TENSE, Tense.PAST);
                    SPhraseSpec p2 = nlgFactory.createClause();
                    NPPhraseSpec subject = nlgFactory.createNounPhrase("The teams");
                    NPPhraseSpec object = nlgFactory.createNounPhrase("each other");
                    VPPhraseSpec verb = nlgFactory.createVerbPhrase("fought");
                    p2.setSubject(subject);
                    p2.setObject(object);
                    p2.setVerb(verb);
                    p2.setFeature(Feature.TENSE, Tense.PAST);
                    p2.addComplement("tooth and nail in an equally matched game.");
                    p2.addComplement("It was back and forth all four quarters, but ultimately both teams tied for " + For);
                    DocumentElement s1 = nlgFactory.createSentence(p1);
                    DocumentElement s2 = nlgFactory.createSentence(p2);
                    DocumentElement par1 = nlgFactory.createParagraph(Arrays.asList(s1, s2));

                    String output = realiser.realise(par1).getRealisation();
                    out.println(output);
                    System.out.println(output);
                } else {
                    System.out.println("Report Print Error");
                            }
                        }
            out.println("End of games played to" + DATE2);
            System.out.println("End of games played to" + DATE2);
                    } // end try
        //Exception handling
        catch (ClassNotFoundException classNotFoundException) {
            classNotFoundException.printStackTrace();
        } catch (SQLException throwables) {
            throwables.printStackTrace();
        }
        out.close();
        System.out.println();

                    //close out of the connections
                    try{
                        if(conn != null)
                            conn.close();
                    }catch(SQLException se){
                        se.printStackTrace();
                    }//end finally try
        //Opens CommishCorner.txt
        if(file.exists())
            desktop.open(file);
        //Prints end statement to the console
        System.out.println("Goodbye!");
                } //end main

            }//end class

